aboutsummaryrefslogtreecommitdiff
path: root/conn/conn.go
diff options
context:
space:
mode:
Diffstat (limited to 'conn/conn.go')
-rw-r--r--conn/conn.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/conn/conn.go b/conn/conn.go
index a9c70b5..a1f57d2 100644
--- a/conn/conn.go
+++ b/conn/conn.go
@@ -45,9 +45,9 @@ type Bind interface {
// This mark is passed to the kernel as the socket option SO_MARK.
SetMark(mark uint32) error
- // Send writes one or more packets in buffs to address ep. The length of
- // buffs must not exceed BatchSize().
- Send(buffs [][]byte, ep Endpoint) error
+ // Send writes one or more packets in bufs to address ep. The length of
+ // bufs must not exceed BatchSize().
+ Send(bufs [][]byte, ep Endpoint) error
// ParseEndpoint creates a new endpoint from a string.
ParseEndpoint(s string) (Endpoint, error)